==> sparc-rtems-4.6.6-gcc-3.2.3-1.0.20-linux.tar.bz2: rtems-4.6/sparc-rtems/erc32/lib/include/rtems/init.h <==
/*  init.h
 *
 *  This include file contains all the constants and structures associated
 *  with the Initialization Manager.  This manager is responsible for
 *  initializing RTEMS, creating and starting all configured initialization
 *  tasks, invoking the initialization routine for each user-supplied device
 *  driver, and initializing the optional multiprocessor layer.
 *
 *  This manager provides directives to:
 *
 *     + initialize the RTEMS executive
 *     + shutdown the RTEMS executive
 *
 *
 *  COPYRIGHT (c) 1989-1999.
 *  On-Line Applications Research Corporation (OAR).
 *
 *  The license and distribution terms for this file may be
 *  found in the file LICENSE in this distribution or at
 *  http://www.rtems.com/license/LICENSE.
 *
 *  $Id: init.h,v 1.9.6.1 2003/09/04 18:47:20 joel Exp $
 */

#ifndef __RTEMS_INIT_h
#define __RTEMS_INIT_h

#ifdef __cplusplus
extern "C" {
#endif

#include <rtems/rtems/types.h>
#include <rtems/config.h>
#include <rtems/rtems/intr.h>

/*
 *  The following defines the default Multiprocessing Configuration
 *  Table.  This table is used in a single processor system.
 */

extern const rtems_multiprocessing_table
  _Initialization_Default_multiprocessing_table;

/*
 *  rtems_initialize_executive
 *
 *  DESCRIPTION:
 *
 *  This routine implements the rtems_initialize_executive directive.  This
 *  directive is invoked at system startup to initialize the RTEMS
 *  multitasking environment.
 */

void rtems_initialize_executive(
  rtems_configuration_table *configuration_table,
  rtems_cpu_table           *cpu_table
);

/*
 *  rtems_initialize_executive_early
 *
 *  DESCRIPTION:
 *
 *  This routine implements the early portion of rtems_initialize_executive
 *  directive up to the pretasking hook. This directive is invoked at system
 *  startup to initialize the RTEMS multitasking environment.
 */

rtems_interrupt_level rtems_initialize_executive_early(
  rtems_configuration_table *configuration_table,
  rtems_cpu_table           *cpu_table
);

/*
 *  rtems_initialize_executive_late
 *
 *  DESCRIPTION:
 *
 *  This routine implements the early portion of rtems_initialize_executive
 *  directive up to the pretasking hook. This directive is invoked at system
 *  startup to initialize the RTEMS multitasking environment.
 */

void rtems_initialize_executive_late(
  rtems_interrupt_level bsp_level
);

/*
 *  rtems_shutdown_executive
 *
 *  DESCRIPTION:
 *
 *  This routine implements the rtems_shutdown_executive directive.  The
 *  invocation of this directive results in the RTEMS environment being
 *  shutdown and multitasking halted.  From the application's perspective,
 *  invocation of this directive results in the rtems_initialize_executive
 *  directive exitting to the startup code which invoked it.
 */

void rtems_shutdown_executive(
  unsigned32 result
);

#ifdef __cplusplus
}
#endif

#endif
/* end of include file */

==> sparc-rtems-4.10-gcc-4.4.6-1.2.21-linux.tar.bz2: rtems-4.10/sparc-rtems/erc32/lib/include/rtems/init.h <==
/**
 * @file rtems/init.h
 *
 *
 *  This include file contains all the constants and structures associated
 *  with the Initialization Manager.  This manager is responsible for
 *  initializing RTEMS, creating and starting all configured initialization
 *  tasks, invoking the initialization routine for each user-supplied device
 *  driver, and initializing the optional multiprocessor layer.
 *
 *  This manager provides directives to:
 *
 *     + initialize the RTEMS executive
 *     + shutdown the RTEMS executive
 */

/*
 *  COPYRIGHT (c) 1989-2008.
 *  On-Line Applications Research Corporation (OAR).
 *
 *  The license and distribution terms for this file may be
 *  found in the file LICENSE in this distribution or at
 *  http://www.rtems.com/license/LICENSE.
 *
 *  $Id$
 */

#ifndef _RTEMS_INIT_H
#define _RTEMS_INIT_H

#ifdef __cplusplus
extern "C" {
#endif

#include <rtems/rtems/types.h>
#include <rtems/config.h>
#include <rtems/rtems/intr.h>

#if defined(RTEMS_MULTIPROCESSING)
/**
 *  The following defines the default Multiprocessing Configuration
 *  Table.  This table is used in a single processor system.
 */
extern const rtems_multiprocessing_table
  _Initialization_Default_multiprocessing_table;
#endif

/**
 *  @brief rtems_initialize_data_structures
 *
 *  This routine implements the portion of the RTEMS initializatin process
 *  that involves initializing data structures to a state that scheduling
 *  can occur in a consistent manner.
 */
void rtems_initialize_data_structures(void);

/**
 *  @brief rtems_initialize_before_drivers
 *
 *  This routine implements the portion of RTEMS initialization that
 *  is done immediately before device drivers are initialized.
 */
void rtems_initialize_before_drivers(void);

/**
 *  @brief rtems_initialize_device_drivers
 *
 *  This routine implements the portion of RTEMS initialization that
 *  initializes all device drivers.
 */
void rtems_initialize_device_drivers(void);

/**
 *  @brief rtems_initialize_start_multitasking
 *
 *  This routine implements the early portion of rtems_initialize_executive
 *  directive up to the pretasking hook. This directive is invoked at system
 *  startup to initialize the RTEMS multitasking environment.
 */
void rtems_initialize_start_multitasking(void);

/**
 *  @brief rtems_shutdown_executive
 *
 *  This routine implements the rtems_shutdown_executive directive.  The
 *  invocation of this directive results in the RTEMS environment being
 *  shutdown and multitasking halted.  From the application's perspective,
 *  invocation of this directive results in the rtems_initialize_executive
 *  directive exitting to the startup code which invoked it.
 */
void rtems_shutdown_executive(
  uint32_t   result
);

#ifdef __cplusplus
}
#endif

#endif
/* end of include file */
